<?php
/* 
Plugin Name: PrivateContent
Plugin URI: www.persianscript.ir
Description: The WordPress membership solution
Author: پرشین اسکریپت
Version: 7.4.6
Author URI: www.persianscript.ir
*/  


/////////////////////////////////////////////
/////// MAIN DEFINES ////////////////////////
/////////////////////////////////////////////

// plugin path
$wp_plugin_dir = substr(plugin_dir_path(__FILE__), 0, -1);
define('PC_DIR', $wp_plugin_dir);

// plugin url
$wp_plugin_url = substr(plugin_dir_url(__FILE__), 0, -1);
define('PC_URL', $wp_plugin_url);


// plugin version
define('PC_VERS', '7.4.6');

// multilanguage id
define('PC_ML', 'pc_ml');





/////////////////////////////////////////////
/////// FORCING DEBUG ///////////////////////
/////////////////////////////////////////////

if(isset($_REQUEST['pc_php_debug'])) {
	ini_set('display_errors', 1);
	ini_set('display_startup_errors', 1);
	error_reporting(E_ALL);	
}






/////////////////////////////////////////////
/////// MULTILANGUAGE SUPPORT ///////////////
/////////////////////////////////////////////

function pc_multilanguage() {
  $param_array = explode(DIRECTORY_SEPARATOR, PC_DIR);
  $folder_name = end($param_array);
  
  if(is_admin()) {
	 load_plugin_textdomain(PC_ML, false, $folder_name . '/lang_admin');  
  }
  load_plugin_textdomain(PC_ML, false, $folder_name . '/languages');  
}
add_action('init', 'pc_multilanguage', 1);







/////////////////////////////////////////////
/////// DATABASE MANAGEMENT /////////////////
/////////////////////////////////////////////

// database table constants
function pc_db_constants() {
	global $wpdb;
	
	if(!defined('PC_USERS_TABLE')) {
		define('PC_USERS_TABLE', $wpdb->prefix . "pc_users");
		define('PC_META_TABLE', $wpdb->prefix . "pc_user_meta");
	}
}
add_action('init', 'pc_db_constants', 1);


function pc_db_manag() {
	include_once(PC_DIR . '/db_manag.php');
}
register_activation_hook(__FILE__, 'pc_db_manag');

// do also on specific recall
if(isset($_GET['pc_db_check'])) { 
	function pc_forced_db_manag() {
		pc_db_manag(); 
	}
	add_action('admin_init', 'pc_forced_db_manag', 1);
}








/////////////////////////////////////////////
/////// WP USERS SYNC INITIALIZATION ////////
/////////////////////////////////////////////

function pc_wp_user_sync_init() {
	global $pc_users;
	
	if($pc_users->wp_user_sync) {
		include_once(PC_DIR . '/wp_user_tricks.php');
		
		add_role('pvtcontent', 'PrivateContent',
			array(
				'read'         => true,
				'edit_posts'   => false,
				'delete_posts' => false
			)
		);
	} else {
		remove_role('pvtcontent');
	}
}
add_action('init', 'pc_wp_user_sync_init', 1);








/////////////////////////////////////////////
/////// CURRENT USER CAN EDIT? GLOBAL FLAG //
/////////////////////////////////////////////

function pc_cuc_flag() {
	$au_cap = get_option('pg_min_role_tmu', get_option('pg_min_role', 'upload_files'));
	$cuc = (empty($au_cap)) ? true :  current_user_can($au_cap);
		
	if($cuc && !is_admin() && current_user_can('pvtcontent')) {
		$cuc = false;
	}
	
	$GLOBALS['pc_cuc_edit'] = $cuc;	
}
add_action('init', 'pc_cuc_flag', 10); // must be exec after pc_init_session_check_cookie()








///////////////////////////////////////////////////////////////
/////// FLAG FOR LOGGED WP USER - IF CAN BYPASS RESTRICTIONS //
///////////////////////////////////////////////////////////////

function pc_testing_mode_flag() {
	if(!is_admin() && !defined('PC_WP_USER_PASS')) {
		$pc_min_role = get_option('pg_min_role', 'upload_files');	
		$testing_mode = get_option('pg_test_mode');
		$GLOBALS['pc_testing_mode'] = $testing_mode;
		
		if($testing_mode) {
			$val = (!is_user_logged_in() || !current_user_can($pc_min_role)) ? true : false;
		} else {
			$val = (!is_user_logged_in() || !current_user_can($pc_min_role)) ? false : true;	
		}

		define('PC_WP_USER_PASS', $val);
	}
}
add_action('init', 'pc_testing_mode_flag', 1);







/////////////////////////////////////////////
/////// MAIN SCRIPT & CSS INCLUDES //////////
/////////////////////////////////////////////

// global script enqueuing
function pc_global_scripts() { 
	wp_enqueue_script("jquery"); 
	wp_enqueue_style('pc-fontawesome', PC_URL .'/css/fontAwesome/css/all.min.css', 999, '5.15.2');

	$is_admin = is_admin();
	
	// admin css
	if($is_admin) {  
        global $current_screen;
        if(!$current_screen) {
            return;    
        }
        
		wp_enqueue_style('pc_admin', PC_URL .'/css/admin.css', 999, PC_VERS);	
		
		// add tabs scripts
		wp_enqueue_script('jquery-ui-core');
		wp_enqueue_script('jquery-ui-sortable');
		
        
        // LC tools
        wp_enqueue_script('lc-switch-v2',       PC_URL .'/js/lc-switch/lc_switch.min.js', 200, '2.0.3', true);
        wp_enqueue_script('lc-range-n-num',     PC_URL .'/js/lc-range-n-num/lc_range_n_num.min.js', 200, '1.0.1', true);
        wp_enqueue_script('lc-wp-popup-message',PC_URL .'/js/lc-wp-popup-message/lc_wp_popup_message.min.js', 200, '1.0', true);
        
        wp_enqueue_style('lcwp-lc-select',      PC_URL .'/js/lc-select/themes/lcwp_prefixed.css');
        wp_enqueue_script('lc-select',          PC_URL .'/js/lc-select/lc_select.min.js', 100, '1.1.4', true);
        
        
        // magpop
        wp_enqueue_style('lcwp_magpop', PC_URL .'/js/magnific_popup/magnific-popup.css');
        wp_enqueue_script('lcwp_magpop', PC_URL .'/js/magnific_popup/magnific-popup.pckg.js', 100, '1.1.0', true);
        
        
        // settings page scripts
        if($current_screen->base == 'privatecontent_page_pc_settings') {
            $baseurl = PC_URL .'/js';
            wp_enqueue_style('pc_settings', PC_URL .'/settings/settings_style.css', 999, PC_VERS);	

            wp_enqueue_script('lc-color-picker',    $baseurl .'/lc-color-picker/lc_color_picker.min.js', 200, '1.1.1', true);
            
            wp_enqueue_style('codemirror',          $baseurl .'/codemirror/codemirror.css');
            wp_enqueue_script('codemirror',         $baseurl .'/codemirror/codemirror.min.js', 200, '1.0', true);
            wp_enqueue_script('codemirror-lang-css',$baseurl .'/codemirror/languages/css.min.js', 201, '1.0', true);
        }
	}
	
	
	// login, registering and logout JS file
	if(!$is_admin || isset($GLOBALS['lc_guten_scripts'])) {
		wp_enqueue_script('pc_frontend', PC_URL . '/js/frontend.min.js', 999, PC_VERS, true);	
		wp_enqueue_style('pc_multiselect', PC_URL.'/js/multiple-select/multiple-select.css', 50, PC_VERS);
		wp_enqueue_script('pc_multiselect', PC_URL . '/js/multiple-select/multiple.select.min.js', 999, PC_VERS, true);	
		
		// if using recaptcha system
		if(get_option('pg_antispam_sys') == 'recaptcha') {
			wp_enqueue_script('grecaptcha', 'https://www.google.com/recaptcha/api.js?render='.get_option('pg_recaptcha_public'));	
		}
		
		add_action('wp_head', 'pc_dynamic_js_vars', 50);
		add_action('lc_scripts_in_guten_head', 'pc_dynamic_js_vars');
	}
    
    
	
	// lightbox scripts - only if there are instances
	if(!is_admin() && wp_count_terms('pc_lightboxes', array('hide_empty' => false))) {
		$GLOBALS['pc_has_lightboxes'] = true;
		
		wp_enqueue_style('pc_lightbox', PC_URL.'/js/magnific_popup/magnific-popup.css', 50, PC_VERS);	
		wp_enqueue_script('pc_lightbox', PC_URL . '/js/magnific_popup/magnific-popup.pckg.js', 999, PC_VERS, true);	
	}
	
    
    
	// custom frontend style - only if is not disabled by settings
	if((!$is_admin || isset($GLOBALS['lc_guten_scripts'])) && !get_option('pg_disable_front_css')) {  
		$style = get_option('pg_style', 'minimal');
		wp_enqueue_style('pc_frontend', PC_URL .'/css/frontend.min.css', 998, PC_VERS);
        
		if((!get_option('pg_inline_css') && !get_option('pg_force_inline_css')) || $style != 'custom') {
			wp_enqueue_style('pc_style', PC_URL . '/css/'.$style.'.css', 999, PC_VERS .'-'. get_option('pc_dynamic_scripts_id'));		
		} else {
			add_action('wp_head', 'pc_inline_css', 989);
		}
	}
}
add_action('wp_enqueue_scripts', 'pc_global_scripts', 900);
add_action('admin_enqueue_scripts', 'pc_global_scripts');
add_action('lc_guten_scripts', 'pc_global_scripts');



// dynamic javascript vars
function pc_dynamic_js_vars() {
	$code = '<script type="text/javascript">';
		
	// multi-select variable to translate
	$code .= 'pc_ms_countSelected = "'. esc_attr__('# of % selected', PC_ML) .'";'; 
	$code .= 'pc_ms_allSelected = "'. esc_attr__('All selected', PC_ML) .'";';
	
	// HTML5 forms validation flag
	$result = (get_option('pg_no_html5_validation')) ? 'false' : 'true'; 
	$code .= 'pc_html5_validation = '.$result.';';
	
	// dropdown texts
	$code .= 'pc_ms_search_placeh = "'. esc_attr__('Search options', PC_ML) .'";'; 
	$code .= 'pc_ms_search_nores = "'. esc_attr__('No matches found', PC_ML) .'";'; 
	
	echo $code .'</script>';
}




// use custom style inline
function pc_inline_css(){
	if(isset($GLOBALS['pc_printed_inline_css'])) { // avoid double enqueuing with Gutenberg
		return false;	
	}
	$GLOBALS['pc_printed_inline_css'] = true;
	
	echo '<style type="text/css">';
	include_once(PC_DIR.'/custom_style.php');
	echo '</style>';
}



// custom css
function pc_custom_css(){

	/* PC-ACTION - allows custom CSS to be directly printed inline (before PC custom CSS) */
	do_action('pc_inline_css');
	
	$code = trim(get_option('pg_custom_css', ''));
	if($code) {
		echo '
<!-- privateContent custom CSS -->
<style type="text/css">'. $code .'</style>
';
	}
}
add_action('wp_head', 'pc_custom_css', 999);







// forms style, bottom-border and no-label style - body class
function pc_body_tag_class($classes) { 
    $classes[] = 'pc_'. get_option('pg_style', 'minimal') .'_style';
	
	if(get_option('pg_bottomborder')) {
		$classes[] = 'pc_bottomborder';	
	}
	if(get_option('pg_nolabel')) {
		$classes[] = 'pc_nolabel';	
	}
	return $classes;
}
add_filter('body_class', 'pc_body_tag_class');	
	







//////////////////////////////////////////////////
/////////// MAIN INCLUDES ////////////////////////
//////////////////////////////////////////////////

// STATIC METHODS
include_once(PC_DIR . '/classes/pc_static.php');

// USERS MANAGEMENT CLASS
include_once(PC_DIR . '/classes/users_manag.php');

// WP-SYNC MANAGEMENT CLASS
include_once(PC_DIR . '/classes/wp_user_sync.php');

// META MANAGEMENT CLASS
include_once(PC_DIR . '/classes/meta_manag.php');

// USER AUTH SYSTEM - SESSION SETUP - AJAX LOGIN & LOGOUT
include_once(PC_DIR . '/user_auth.php');

// FRONT AJAX OPERATIONS (user deletion)
include_once(PC_DIR . '/front_ajax.php');

// GOOGLE ANALYTICS CLASS
include_once(PC_DIR . '/classes/google_analytics.php');



// MENU AND TOPBAR PENDING USERS 
include_once(PC_DIR . '/admin_menu.php');

// USER CAT - CUSTOM FIELDS
include_once(PC_DIR . '/user_categories.php');

// PUBLIC API
include_once(PC_DIR . '/public_api.php');

// ADMIN AJAX
include_once(PC_DIR . '/admin_ajax.php');

// USER DASHBOARD AJAX
include_once(PC_DIR . '/user_dashboard/ajax.php');

// CUSTOM POST TYPES AND TAXONOMIES DECLARATION
include_once(PC_DIR . '/cpt_and_ct.php');

// RESTRICTIONS WIZARD
include_once(PC_DIR . '/classes/restrictions_wizard.php');

// NAV MENU OPTION
include_once(PC_DIR . '/nav_menu_option.php');

// TINYMCE BUTTON
include_once(PC_DIR . '/tinymce_implementation.php');



// POSTS RESTRICTIONS CACHE
include_once(PC_DIR . '/classes/posts_restr_cache.php');

// SHORTCODES
include_once(PC_DIR . '/shortcodes.php');

// LIGHTBOX ENGINE
include_once(PC_DIR . '/lightbox_engine.php');

// USER REGISTRATION SYSTEM
include_once(PC_DIR . '/user_registration.php');

// LOGIN WIDGET
include_once(PC_DIR . '/login_widget.php');

// USERS PRIVATE PAGE
include_once(PC_DIR . '/user_pvt_page.php');



// COMMENTS RESTRICTION
include_once(PC_DIR . '/restrictions/comments_restriction.php');

// CONTENTS HIDING ENGINE
include_once(PC_DIR . '/restrictions/contents_hiding.php');

// MENU RESTRICTION
include_once(PC_DIR . '/restrictions/menu_restriction.php');

// REDIRECT ENGINE
include_once(PC_DIR . '/restrictions/redirect_engine.php');

// WIDGET RESTRICTION
include_once(PC_DIR . '/restrictions/widgets_restriction.php');

// LIGHTBOX ON PAGE'S OPENING
include_once(PC_DIR . '/restrictions/lightbox_on_opening.php');




// gutenberg integration - not for WP 5.8 widgets.. for now
if($_SERVER["REQUEST_URI"] != '/wp-admin/widgets.php') {
    include_once(PC_DIR . '/builders_integration/gutenberg.php');
}

// visual composer integration
include_once(PC_DIR . '/builders_integration/visual_composer.php');

// cornerstone integration
include_once(PC_DIR . '/builders_integration/cornerstone.php');

// elementor integration
include_once(PC_DIR . '/builders_integration/elementor.php');







////////////
// DOCUMENTATION'S LINK IN PLUGINS LIST
if(!isset($GLOBALS['is_pc_bundle'])) {
	
	function pc_doc_link($links, $file) {
		if($file == plugin_basename(__FILE__)) {	
			$links['lc_doc_link'] = '<a href="https://doc.lcweb.it/privatecontent" target="_blank">'. esc_html__('Documentation', PC_ML) .'</a>';
		}
		
		return $links;
	}
	add_filter('plugin_row_meta', 'pc_doc_link', 50, 2);
}
////////////




////////////
// AUTO UPDATE DELIVER
if(!isset($GLOBALS['is_pc_bundle'])) {
	function pc_auto_updates() {
		if(!get_option('pg_no_auto_upd')) {
            include_once(PC_DIR .'/classes/lc_wp_auto_updater/lc_plugin_auto_updater.php');
            
			$upd = new lc_wp_autoupdate(__FILE__, 'http://updates.lcweb.it', 'lc_updates', 'pc_on_activation');
            $upd->ml_key = PC_ML;
		}
	}
	add_action('admin_init', 'pc_auto_updates', 1);
}
////////////








//////////////////////////////////////////////////
// ACTIONS ON PLUGIN ACTIVATION //////////////////
//////////////////////////////////////////////////

function pc_on_activation($networkwide = false) {

    // prevent multisite activation
    if (is_multisite() && $networkwide) {
        wp_die('PrivateContent cannot be network activated. Please enable it into subsites panel');
    }
    
	// create custom form style
	if(get_option('pg_style') == 'custom') {
		if(!pc_static::create_custom_style()) {update_option('pg_inline_css', 1);}
		else {delete_option('pg_inline_css');}
	}

	// minimum role to use plugin
	if(!get_option('pg_min_role')) {
		update_option('pg_min_role', 'upload_files');
	}
	
	// update v6.1 - reset antispam - recaptcha must be configured!
	if(!get_option('pg_recaptcha_public')) {
		delete_option('pg_antispam_sys');	
	}
}
register_activation_hook(__FILE__, 'pc_on_activation');





//////////////////////////////////////////////////
// export users security trick - avoid issues related to php warnings
function pc_export_buffer() {
	ob_start();
}
add_action('admin_init', 'pc_export_buffer', 2);









/////////////////////////////////////////////
// RETROCOMPATIBILITY FOR ADD-ONS BEFORE v5 /
/////////////////////////////////////////////

$retro_pc_dir = PC_DIR; define('PG_DIR', $retro_pc_dir);
$retro_pc_url = PC_URL; define('PG_URL', $retro_pc_url);

//////////////////////////////////////////////////////
